@@ -19,7 +19,9 @@
 #define LIBPLACEBO_COLORSPACE_H_
 
 #include <stdbool.h>
+#include <stddef.h>
 #include <stdint.h>
+
 #include <libplacebo/common.h>
 
 // The underlying color representation (e.g. RGB, XYZ or YCbCr)
@@ -74,9 +76,13 @@ enum pl_channel {
 // The numerical range of the representation (where applicable).
 enum pl_color_levels {
     PL_COLOR_LEVELS_UNKNOWN = 0,
-    PL_COLOR_LEVELS_TV,         // TV range, e.g. 16-235
-    PL_COLOR_LEVELS_PC,         // PC range, e.g. 0-255
+    PL_COLOR_LEVELS_LIMITED,    // Limited/TV range, e.g. 16-235
+    PL_COLOR_LEVELS_FULL,       // Full/PC range, e.g. 0-255
     PL_COLOR_LEVELS_COUNT,
+
+    // Compatibility aliases
+    PL_COLOR_LEVELS_TV = PL_COLOR_LEVELS_LIMITED,
+    PL_COLOR_LEVELS_PC = PL_COLOR_LEVELS_FULL,
 };
 
 // The alpha representation mode.
@@ -84,6 +90,7 @@ enum pl_alpha_mode {
     PL_ALPHA_UNKNOWN = 0,   // or no alpha channel present
     PL_ALPHA_INDEPENDENT,   // alpha channel is separate from the video
     PL_ALPHA_PREMULTIPLIED, // alpha channel is multiplied into the colors
+    PL_ALPHA_MODE_COUNT,
 };
 
 // The underlying bit-wise representation of a color sample. For example,
@@ -159,6 +166,7 @@ enum pl_color_primaries {
     PL_COLOR_PRIM_BT_601_625,   // ITU-R Rec. BT.601 (625-line = PAL, SECAM)
     PL_COLOR_PRIM_BT_709,       // ITU-R Rec. BT.709 (HD), also sRGB
     PL_COLOR_PRIM_BT_470M,      // ITU-R Rec. BT.470 M
+    PL_COLOR_PRIM_EBU_3213,     // EBU Tech. 3213-E / JEDEC P22 phosphors
     // Wide gamut:
     PL_COLOR_PRIM_BT_2020,      // ITU-R Rec. BT.2020 (UltraHD)
     PL_COLOR_PRIM_APPLE,        // Apple RGB
@@ -169,6 +177,7 @@ enum pl_color_primaries {
     PL_COLOR_PRIM_DISPLAY_P3,   // DCI-P3 (Digital Cinema) with D65 white point
     PL_COLOR_PRIM_V_GAMUT,      // Panasonic V-Gamut (VARICAM)
     PL_COLOR_PRIM_S_GAMUT,      // Sony S-Gamut
+    PL_COLOR_PRIM_FILM_C,       // Traditional film primaries with Illuminant C
     PL_COLOR_PRIM_COUNT
 };
 
@@ -385,6 +394,11 @@ struct pl_matrix3x3 pl_get_color_mapping_matrix(const struct pl_raw_primaries *s
                                                 const struct pl_raw_primaries *dst,
                                                 enum pl_rendering_intent intent);
 
+// Returns true if 'b' is entirely contained in 'a'. Useful for figuring out if
+// colorimetric clipping will occur or not.
+bool pl_primaries_superset(const struct pl_raw_primaries *a,
+                           const struct pl_raw_primaries *b);
+
 // Cone types involved in human vision
 enum pl_cone {
     PL_CONE_L = 1 << 0,
@@ -473,4 +487,9 @@ struct pl_icc_profile {
 bool pl_icc_profile_equal(const struct pl_icc_profile *p1,
                           const struct pl_icc_profile *p2);
 
+// Sets `signature` to a hash of `profile->data`, if non-NULL. Provided as a
+// convenience function for the sake of users ingesting arbitrary ICC profiles
+// from sources where they can't reliably detect profile changes.
+void pl_icc_profile_compute_signature(struct pl_icc_profile *profile);
+
 #endif // LIBPLACEBO_COLORSPACE_H_
